#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'pushover_snapshot.ps1'
#   2. This script must be located in the same folder as script 'pushover_snapshot.ps1'
#   3. This script is suitable for 'pushover_snapshot.ps1' versions V1+
#
# REQUIRES: 
#   'pushover_snapshot.ps1'
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# ENTER APPLICATION'S WORKING FOLDER
	# ... Folder location for script's attachment images and CSV logfile
	# ... Default is 'C:\temp\pushover_snapshot'
	#$app_path = 'D:\pushover_snapshot'
	$app_path = 'YOUR_DESTINATION_FOLDER_PATH'

	# ENTER BLUE IRIS NEW FOLDER
	# ... Default is 'C:\temp\pushover_snapshot'
	#$bi_new_path = 'D:\BlueIris\New'
	$bi_new_path = 'YOUR_BLUE_IRIS_NEW_FOLDER_PATH'

	# ENTER PUSHOVER API APPLICATION TOKEN
	# ... TIP: consider adding a 'PowerShell' application to your https://pushover.net/ account
	$po_app_token = "YOUR_API_APPLICATION_TOKEN"

	# ENTER PUSHOVER API USER KEY
	# ... https://pushover.net/
	$po_user_token = "YOUR_API_USER_KEY"

# OPTIONAL SETTINGS

	# APP SETTINGS
	
		# OPT IN/OUT OF BACKGROUND MESSAGING
		# ... [boolean]
		# ... Default is $true
		# ... Key Points: 
		#     1. Background messages are enabled only if script is running in the bacground
		#     2. This global setting may be overridden by argument '-Quiet Y'
		#$bg_msgs_flg = $true
		#$bg_msgs_flg = $false

	# SNAPSHOT SETTINGS

		# ENTER CUSTOM DELAY TIME AFTER TAKING SNAPSHOT
		# ... Avoids a race condition where script looks for the latest snapshot JPG file 
		#     before the Windows filesystem is ready
		# ... Default is 500
		#$snap_delay_ms = 500

		# ENTER CUSTOM MEMO TEXT FOR SNAPSHOTS CREATED BY THIS SCRIPT
		# ... Default is scriptname ('pushover_snapshot.ps1')
		# ... Note: blank disables this feature
		#$snap_memo = "YOUR_CUSTOM_MEMO_TEXT"

	# PUSHOVER SETTINGS

		# ENTER CUSTOM PUSHOVER MESSAGE TITLE
		# ... default is "from pushover_snapshot.ps1"
		#$po_title = "MY_CUSTOM_TITLE"

		# ENTER DEFAULT PUSHOVER MESSAGE PRIORITY
		# ... (integer) -2|-1|0|1|2; -2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency
		# ... default is 0
		# ... see https://pushover.net/api#priority
		$po_priority = 0

		# ENTER CUSTOM PUSHOVER SOUND
		# ... blank ("") is default sound
		# ... see https://pushover.net/api#sounds
		$po_sound = ""  # default sound
		#$po_sound = "siren"  # built-in sound
		#$po_sound = "not-kiddin"  # custom sound

		# ENTER PREFERRED PUSHOVER DEVICE(S)
		# ... blank ("") sends to all devices
		# ... may be comma-delimited list.
		# ... see https://pushover.net/api
		$po_device = ""  # all devices
		#$po_device = "galaxy-s21"  # single device
		#$po_device = "galaxy-s21,iPhoneXS"  # multiple devices

		# ENTER DEFAULT PUSHOVER EMERGENCY RETRY PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... see https://pushover.net/api#priority
		$po_retry = 30

		# ENTER DEFAULT PUSHOVER EMERGENCY EXPIRE PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... see https://pushover.net/api#priority
		$po_expire = 300

		# ENTER DEFAULT PUSHOVER EMERGENCY PRIORITY TAGS
		# ... blank ("") is default tag
		# ... see https://pushover.net/api#priority
		$po_tags = ""
		#$po_tags = "a=BI,c=&CAM,g=Front"  # custom tags

	# PUSHOVER ATTACHMENT IMAGE RESIZING

		# ENTER NEW IMAGE QUALITY
		# ... [integer] 0 to 100
		# ... Default is 90
		# ... Note: if 100 with $img_width = 0, the image is used as-is (unresized)
		#$img_quality = 90

		# ENTER NEW IMAGE WIDTH DIMENSION
		# ... [integer] units are pix
		# ... Default is 500
		# ... The aspect ratio is unchanged by resizing
		# ... Note: if 0 with $img_quality < 100, the target width = the source image width
		# ...       if 0 with $img_quality = 100, the image is used as-is
		#$img_width = 0
		#$img_width = 500

		# ENTER NEW IMAGE KB TARGET
		# ... [integer] units are kilobytes
		# ... If nonzero, the image dimensions (WxH) will be iteratively resized by -25% increments
		#     until the file size is under the target size; 3 iterations max
		# ... If zero, the image is resized based on $img_quality & $img_width settings
		# ... Default is 0
		$img_kilobytes = 0

		# CHANGE DEFAULT -TargetKB RESIZING METHOD
		# ... [string] 'WxH', 'Quality', 'Hybrid'
		# ... Default is 'WxH'
		#$targetkb_method = 'Quality'
		#$targetkb_method = 'Hybrid'

		# CHANGE -TargetKB Hybrid DIMENSIONS STEP
		# ... This value will be used in a loop to sequentially reduce the image's dimensions
		# ... Used only if $targetkb_method = 'WxH' or 'Hybrid'
		# ... [integer] 0-99
		# ... Default is 25
		#$targetkb_wxh_step = 25
		#$targetkb_wxh_step = 20

		# CHANGE -TargetKB Hybrid QUALITY STEP
		# ... This value will be used in a loop to sequentially reduce the image's quality  
		# ... Used only if $targetkb_method = 'Quality' or 'Hybrid'
		# ... [integer] 0-99
		# ... Default is 20
		#$targetkb_quality_step = 20
		#$targetkb_quality_step = 10

	# BLUE IRIS LOGFILE

		# OPT-IN TO POST CUSTOM MESSAGES TO THE BLUE IRIS LOGFILE
		# ... expecting $false or $true (default = $false)
		# ... NOTE: $true enables logging regardless the state of the 'Use secure session keys and login page' control
		#     on the Blue Iris Settings > Web server > Advanced page
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

		# NOTE: THE FOLLOWING LINES/REQUIREMENTS ARE IGNORED IF 
		# '$post_to_BI_logfile_flg = $false'

			# ENTER BLUE WEBSERVER ADDRESS & PORT
			$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

			# OPT-IN TO USING CREDENTIALS FOR POSTING TO THE BLUE IRIS LOGFILE
			# ... expecting $false or $true
			# ... If you want to use the user credentials below, then both of following are required:
			#     1. This setting must be = $true
			#     2. The 'Use secure session keys and login page' control must be UNCHECKED on the Blue Iris Settings > Web server > Advanced page
			$post_w_creds_flg = $false
			#$post_w_creds_flg = $true

			# ENTER BLUE IRIS WEBSERVER USERNAME & PASSWORD 
			# ... NOTE: USERNAME MUST BE ADMIN
			# ... NOTE: used only if $post_w_creds_flg = $true
			$bi_user_name = "YOUR_BI_USER_NAME"
			$bi_user_pw = "YOUR_BI_USER_PASSORD"

			# OPT IN TO LOGGING ALL EVENTS (NOT JUST ERRORS)
			# ... [boolean]
			# ... Default is $FALSE
			#$post_all_events = $false
			#$post_all_events = $true

# END USER SETTINGS
# ===============================================
